HandlerWithState

Struct HandlerWithState 

pub struct HandlerWithState<F, S, T, Fut, R>
where F: Fn(State<Arc<S>>, T) -> Fut + Send + Sync, S: Send + Sync + 'static, T: DeserializeOwned + Send, Fut: Future<Output = R> + Send, R: IntoHandlerResult,
{ /* private fields */ }
Wrapper for handlers that receive injected state and typed args

Implementations

Source

impl<F, S, T, Fut, R> HandlerWithState<F, S, T, Fut, R>
where F: Fn(State<Arc<S>>, T) -> Fut + Send + Sync, S: Send + Sync + 'static, T: DeserializeOwned + Send, Fut: Future<Output = R> + Send, R: IntoHandlerResult,

pub fn new( func: F, states: Arc<RwLock<HashMap<TypeId, Arc<dyn Any + Send + Sync>>>>, ) -> HandlerWithState<F, S, T, Fut, R>

Create a new handler with state injection and typed args