pub trait Value: Sealed {
// Required method
fn record(&self, key: &Field, visitor: &mut dyn Visit);
}Expand description
A field value of an erased type.
Implementors of Value may call the appropriate typed recording methods on
the visitor passed to their record method in order to indicate how
their data should be recorded.
Required Methods